==> haskell-incremental-parser-0.5.0.2-55-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-incremental-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 incremental-parser
version:              0.5.0.2
visibility:           public
id:                   incremental-parser-0.5.0.2-INaJI1gxMdU3skmdrpUuVb
key:                  incremental-parser-0.5.0.2-INaJI1gxMdU3skmdrpUuVb
license:              GPL-3.0-only
copyright:            (c) 2011-2018 Mario Blazevic
maintainer:           blamario@yahoo.com
author:               Mario Blazevic
homepage:             https://github.com/blamario/incremental-parser
synopsis:
    Generic parser library capable of providing partial results from partial input.

description:
    This package defines yet another parser combinator library. This one is implemented using the concept of Brzozowski
    derivatives, tweaked and optimized to work with any monoidal input type. Lists, ByteString, and Text are supported out
    of the box, as well as any other data type for which the monoid-subclasses package defines instances. If the parser
    result is also a monoid, its chunks can be extracted incrementally, before the complete input is parsed.

category:             Parsing
abi:                  9dbfc45f07cf8e458ae1c9313941b8bb
exposed:              True
exposed-modules:
    Control.Applicative.Monoid Text.ParserCombinators.Incremental
    Text.ParserCombinators.Incremental.LeftBiasedLocal
    Text.ParserCombinators.Incremental.Symmetric

import-dirs:          /usr/lib/ghc-9.0.1/site-local/incremental-parser-0.5.0.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/incremental-parser-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/incremental-parser-0.5.0.2

hs-libraries:         HSincremental-parser-0.5.0.2-INaJI1gxMdU3skmdrpUuVb
depends:
    base-4.15.0.0 input-parsers-0.2.3-54FwAgmUe7y6HjkIizetGg
    monoid-subclasses-1.1.1-GNkPbNHaJxoBohu4mNVBX
    parsers-0.12.10-9IQPJqe1YO36SVr2t53or4
    rank2classes-1.4.3-HiGTntbK6wM1jOZxcTELBB transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-incremental-parser/html/incremental-parser.haddock

haddock-html:         /usr/share/doc/haskell-incremental-parser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-incremental-parser-0.5.0.2-59-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-incremental-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 incremental-parser
version:              0.5.0.2
visibility:           public
id:                   incremental-parser-0.5.0.2-HqXjDVt3ofWHLG5DtW4Z86
key:                  incremental-parser-0.5.0.2-HqXjDVt3ofWHLG5DtW4Z86
license:              GPL-3.0-only
copyright:            (c) 2011-2018 Mario Blazevic
maintainer:           blamario@yahoo.com
author:               Mario Blazevic
homepage:             https://github.com/blamario/incremental-parser
synopsis:
    Generic parser library capable of providing partial results from partial input.

description:
    This package defines yet another parser combinator library. This one is implemented using the concept of Brzozowski
    derivatives, tweaked and optimized to work with any monoidal input type. Lists, ByteString, and Text are supported out
    of the box, as well as any other data type for which the monoid-subclasses package defines instances. If the parser
    result is also a monoid, its chunks can be extracted incrementally, before the complete input is parsed.

category:             Parsing
abi:                  f65c9d3c13c0cd6ac888cea489ae4921
exposed:              True
exposed-modules:
    Control.Applicative.Monoid Text.ParserCombinators.Incremental
    Text.ParserCombinators.Incremental.LeftBiasedLocal
    Text.ParserCombinators.Incremental.Symmetric

import-dirs:          /usr/lib/ghc-9.0.1/site-local/incremental-parser-0.5.0.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/incremental-parser-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/incremental-parser-0.5.0.2

hs-libraries:         HSincremental-parser-0.5.0.2-HqXjDVt3ofWHLG5DtW4Z86
depends:
    base-4.15.0.0 input-parsers-0.2.3-9BHbgmjQnS1APDfXWa4yQT
    monoid-subclasses-1.1.2-6PmmsvW1qAi47N1mRFXb4p
    parsers-0.12.10-8eZ60JcZDvI6k61PcZhheA
    rank2classes-1.4.3-D9YJgyghg5jB8PZy8uNoyP transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-incremental-parser/html/incremental-parser.haddock

haddock-html:         /usr/share/doc/haskell-incremental-parser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
